Python: module ichorORM.constants

ichorORM.constants | index

`Copyright (c) 2016-2018 Timothy Savannah
Licensed under the terms of the Lesser GNU Lesser General Public License version 2.1
license can be found at https://raw.githubusercontent.com/kata198/ichorORM/master/LICENSE
constants.py - Some constants`

Data
`` |  | FETCH_ALL_FIELDS = 'ALL' JOIN_INNER = 'INNER' JOIN_LEFT = 'LEFT' JOIN_OUTER_FULL = 'OUTER FULL' JOIN_RIGHT = 'RIGHT' SQL_NULL = 'NULL' WHERE_ALL_TYPES = ('AND', 'OR') WHERE_AND = 'AND' WHERE_OR = 'OR' __all__ = ('FETCH_ALL_FIELDS', 'WHERE_AND', 'WHERE_OR', 'WHERE_ALL_TYPES', 'SQL_NULL', 'JOIN_INNER', 'JOIN_LEFT', 'JOIN_RIGHT', 'JOIN_OUTER_FULL')